@@ -27,7 +27,7 @@ e2 <- predictions(
     newdata = datagrid(gear = unique),
     equivalence = c(22, 24)) |>
     poorman::arrange(gear)
-expect_equivalent(e1$z.ratio, e2$statistic.nonsup)
+expect_equivalent(e1$z.ratio, e2$statistic.nonsup, tol = 1e-6)
 expect_equivalent(e1$p.value, e2$p.value.nonsup)
 
 
@@ -79,7 +79,8 @@ e2 <- predictions(
     mod,
     type = "link",
     newdata = datagrid(gear = unique),
-    equivalence = c(.5, 1.5)) |>
+    equivalence = c(.5, 1.5),
+    numderiv = "richardson") |>
     poorman::arrange(gear)
 expect_equivalent(e1$emmean, e2$estimate)
 expect_equivalent(e1$z.ratio, e2$statistic.noninf)
@@ -124,12 +125,12 @@ mm <- marginal_means(
 
 e1 <- test(pa, delta = delta, adjust = "none", side = "nonsuperiority", df = Inf)
 e2 <- hypotheses(mm, equivalence = c(-delta, delta))
-expect_equivalent(e1$z.ratio, e2$statistic.nonsup)
-expect_equivalent(e1$p.value, e2$p.value.nonsup)
+expect_equivalent(e1$z.ratio, e2$statistic.nonsup, tol = 1e-6)
+expect_equivalent(e1$p.value, e2$p.value.nonsup, tol = 1e-6)
 
 e1 <- test(pa, delta = delta, adjust = "none", side = "noninferiority", df = Inf)
 e2 <- hypotheses(mm, equivalence = c(-delta, delta))
-expect_equivalent(e1$z.ratio, e2$statistic.noninf)
+expect_equivalent(e1$z.ratio, e2$statistic.noninf, tolerance = 1e-6)
 expect_equivalent(e1$p.value, e2$p.value.noninf)
 
 e1 <- test(pa, delta = delta, adjust = "none", df = Inf)
