@@ -18,7 +18,7 @@ mod1 <- tobit(
 mfx <- merge(tidy(slopes(mod1, newdata = dat)), stata)
 expect_slopes(mod1, n_unique = 1, newdata = dat)
 expect_equivalent(mfx$estimate, mfx$dydxstata, tolerance = .00001)
-expect_equivalent(mfx$std.error, mfx$std.errorstata, tolerance = .00001)
+expect_equivalent(mfx$std.error, mfx$std.errorstata, tolerance = 1e-4)
 
 stata <- readRDS(testing_path("stata/stata.rds"))$aer_tobit_right
 mod2 <- tobit(
@@ -53,9 +53,9 @@ em2 <- emmeans::emtrends(mod, ~yearsmarried, "yearsmarried", at = list(age = 30,
 em1 <- tidy(em1)
 em2 <- tidy(em2)
 expect_equivalent(mfx$estimate[1], em1$age.trend)
-expect_equivalent(mfx$std.error[1], em1$std.error, tolerance = .00001)
+expect_equivalent(mfx$std.error[1], em1$std.error, tolerance = .001)
 expect_equivalent(mfx$estimate[2], em2$yearsmarried.trend)
-expect_equivalent(mfx$std.error[2], em2$std.error, tolerance = .00002)
+expect_equivalent(mfx$std.error[2], em2$std.error, tolerance = .0002)
 
 
 # predictions: tobit: no validity
