@@ -151,5 +151,21 @@ expect_true(nrow(p) > 1)
 
 
 
+# Issue #844
+df <- transform(mtcars, gear = as.integer(gear))
 
-rm(list = ls())
\ No newline at end of file
+mod <- gam(
+    gear ~ s(hp) + cyl,
+    data = df,
+    family = ocat(R = 5)
+)
+
+pre <- avg_predictions(model = mod)
+slo <- avg_slopes(mod)
+cmp <- comparisons(mod)
+expect_inherits(pre, "predictions")
+expect_inherits(slo, "slopes")
+expect_inherits(cmp, "comparisons")
+
+
+rm(list = ls())
