@@ -1,9 +1,9 @@
 # TODO: CI: See comment in last test for how the intervals are back transformed
 source("helpers.R")
-exit_if_not(EXPENSIVE)
+if (!EXPENSIVE) exit_file("EXPENSIVE")
 using("marginaleffects")
 
-exit_if_not(requiet("modelsummary"))
+requiet("modelsummary")
 tol <- .0001
 
 
@@ -12,27 +12,27 @@ mod <- glm(am ~ vs + mpg, data = mtcars, family = binomial)
 cmp1 <- comparisons(
     mod,
     variables = list(vs = 0:1),
-    transform_pre = function(hi, lo) mean(hi - lo))
+    comparison = function(hi, lo) mean(hi - lo))
 cmp2 <- comparisons(
     mod,
     variables = list(vs = 0:1))
 cmp2 <- tidy(cmp2)
 expect_equivalent(cmp1$estimate, cmp2$estimate)
-expect_equivalent(cmp1$std.error, cmp2$std.error)
+expect_equivalent(cmp1$std.error, cmp2$std.error, tolerance = tol)
 
 
 
 
 # error when function breaks or returns a bad vector
-exit_if_not(requiet("survey"))
+requiet("survey")
 data(nhanes, package = "survey")
 dat <- setNames(nhanes, tolower(names(nhanes)))
 dat$female <- dat$riagendr == 2
 dat$race <- sprintf("race%s", dat$race)
 mod <- glm(hi_chol ~ female, data = dat, family = binomial)
-expect_error(comparisons(mod, transform_pre = function(x) rep(1, 1234)),
+expect_error(comparisons(mod, comparison = function(x) rep(1, 1234)),
              pattern = "numeric vector")
-expect_error(comparisons(mod, transform_pre = function(hi, lo) head(hi - lo)),
+expect_error(comparisons(mod, comparison = function(hi, lo) head(hi - lo)),
              pattern = "numeric vector")
 
 
@@ -46,8 +46,8 @@ acs12 <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/openintro/
 acs12$disability <- as.numeric(acs12$disability == "yes")
 mod <- glm(disability ~ gender, data = acs12, family = binomial)
 
-ard_r <- comparisons(mod, transform_pre = function(hi, lo) lo - hi)
-arr_r <- comparisons(mod, transform_pre = function(hi, lo) mean(lo) / mean(hi))
+ard_r <- comparisons(mod, comparison = function(hi, lo) lo - hi)
+arr_r <- comparisons(mod, comparison = function(hi, lo) mean(lo) / mean(hi))
 
 cols <- c("estimate", "std.error", "conf.low", "conf.high")
 ard_r <- unlist(tidy(ard_r)[, cols])
@@ -67,8 +67,8 @@ acs12 <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/openintro/
 acs12$disability <- as.numeric(acs12$disability == "yes")
 mod <- glm(disability ~ gender + race + married + age, data = acs12, family = binomial)
 
-ard_r <- comparisons(mod, variables = "gender", transform_pre = function(hi, lo) lo - hi)
-arr_r <- comparisons(mod, variables = "gender", transform_pre = function(hi, lo) mean(lo) / mean(hi))
+ard_r <- comparisons(mod, variables = "gender", comparison = function(hi, lo) lo - hi)
+arr_r <- comparisons(mod, variables = "gender", comparison = function(hi, lo) mean(lo) / mean(hi))
 
 cols <- c("estimate", "std.error", "conf.low", "conf.high")
 ard_r <- unlist(tidy(ard_r)[, cols])
@@ -98,18 +98,18 @@ mod <- glm(health ~ insurance + gender + ethnicity + married + age,
 # # Stata CI: exp(r(lnARR)-invnorm(0.975)*r(lnARR_se))
 # lnarr_r <- comparisons(
 #     mod, variables = "insurance",
-#     transform_pre = function(hi, lo) log(mean(hi) / mean(lo)))
+#     comparison = function(hi, lo) log(mean(hi) / mean(lo)))
 # lnarr_r <- tidy(lnarr_r)
 # exp(lnarr_r$estimate - qnorm(0.975) * lnarr_r$std.error)
 # exp(lnarr_r$estimate - qnorm(0.025) * lnarr_r$std.error)
 
 ard_r <- comparisons(
     mod, variables = "insurance",
-    transform_pre = function(hi, lo) hi - lo)
+    comparison = function(hi, lo) hi - lo)
 
 arr_r <- comparisons(
     mod, variables = "insurance",
-    transform_pre = function(hi, lo) mean(hi) / mean(lo))
+    comparison = function(hi, lo) mean(hi) / mean(lo))
 
 cols <- c("estimate", "std.error", "conf.low", "conf.high")
 ard_r <- unlist(tidy(ard_r)[, cols])
@@ -123,8 +123,8 @@ cols <- c("estimate", "conf.low", "conf.high")
 arr_r <- comparisons(
     mod,
     variables = "insurance",
-    transform_pre = function(hi, lo) log(mean(hi) / mean(lo)))
-arr_r <- unlist(tidy(arr_r, transform_post = exp)[, cols])
+    comparison = function(hi, lo) log(mean(hi) / mean(lo)))
+arr_r <- unlist(tidy(arr_r, transform = exp)[, cols])
 expect_equivalent(arr_r, arr_s[c(1, 3, 4)], tolerance = tol)
 
 
@@ -134,19 +134,19 @@ expect_equivalent(arr_r, arr_s[c(1, 3, 4)], tolerance = tol)
 dat <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/carData/TitanicSurvival.csv")
 dat$survived <- as.factor(dat$survived)
 mod <- glm(survived ~ passengerClass + sex, data = dat, family = binomial)
-cmp <- tidy(comparisons(mod, transform_pre = function(hi, lo) mean(hi - lo)))
+cmp <- tidy(comparisons(mod, comparison = function(hi, lo) mean(hi - lo)))
 # bug created duplicate estimates
 expect_equivalent(length(unique(cmp$estimate)), nrow(cmp))
 
 
 
 # TODO: fix eps to make sure slopes() and comparisons() give same result
-# transform_pre slope vs slopes()
+# comparison slope vs slopes()
 mod <- glm(vs ~ mpg + hp, data = mtcars, family = binomial)
 mfx1 <- slopes(mod)
-mfx2 <- comparisons(mod, transform_pre = "dydx")
+mfx2 <- comparisons(mod, comparison = "dydx")
 mfx3 <- slopes(mod, eps = 1e-5)
-mfx4 <- comparisons(mod, transform_pre = "dydx", eps = 1e-5)
+mfx4 <- comparisons(mod, comparison = "dydx", eps = 1e-5)
 expect_equivalent(mfx1$estimate, mfx2$estimate)
 expect_equivalent(mfx1$std.error, mfx2$std.error)
 expect_equivalent(mfx3$estimate, mfx4$estimate)
@@ -157,7 +157,7 @@ expect_equivalent(mfx3$std.error, mfx4$std.error)
 # # label ratios: We don't have fancy ratio labels anymore, because  +1 is a
 # # better label when we do centering.
 # mod <- lm(mpg ~ hp + factor(cyl), data = mtcars)
-# cmp <- comparisons(mod, transform_pre = "ratio")
+# cmp <- comparisons(mod, comparison = "ratio")
 # expect_true(all(grepl("\\/", cmp$contrast)))
 
 
